#' @section Overview:
#' The only thing you need to do is add the periodic information to a
#' data frame with [periodic()]. You then can manually wrap your data around any
#' domain with [wrap()] or just let ggplot2 do it automatically for you
#'
#' @name ggperiodic
#' @docType package
"_PACKAGE"